diff --git a/src/roster_window.py b/src/roster_window.py
index f75c2a5b0605881383172348d9599ad106feb57e..568cac780e1557317ee48978aef8a465807351d0 100644
--- a/src/roster_window.py
+++ b/src/roster_window.py
@@ -1356,7 +1356,7 @@ _('If "%s" accepts this request you will know his status.') %jid)
 				self.plugin.windows[account]['chats']['tabbed'] = \
 					tabbed_chat_window.TabbedChatWindow(contact, self.plugin, account)
 			else:
-				self.plugin.windows[account]['chats']['tabbed'].new_user(contact)
+				self.plugin.windows[account]['chats']['tabbed'].new_tab(contact)
 				
 			self.plugin.windows[account]['chats'][contact.jid] = \
 				self.plugin.windows[account]['chats']['tabbed']
diff --git a/src/tabbed_chat_window.py b/src/tabbed_chat_window.py
index 08d3c38b14864804edb2015fa2bd3f539ad29a15..f7228bd37f70dd61ed92fe2e6a182f9b63f082ca 100644
--- a/src/tabbed_chat_window.py
+++ b/src/tabbed_chat_window.py
@@ -53,10 +53,10 @@ class TabbedChatWindow(chat.Chat):
 		self.possible_inactive_timeout_id = {}
 		self.TARGET_TYPE_URI_LIST = 80
 		self.dnd_list = [ ( 'text/uri-list', 0, self.TARGET_TYPE_URI_LIST ) ]
-		self.new_user(user)
+		self.new_tab(user)
 		self.show_title()
 		
 		# NOTE: if it not a window event, connect in new_user function
 		signal_dict = {
 'on_tabbed_chat_window_destroy': self.on_tabbed_chat_window_destroy,
 'on_tabbed_chat_window_delete_event': self.on_tabbed_chat_window_delete_event,
@@ -350,7 +350,7 @@ timestamp, contact):
 		chat.Chat.remove_tab(self, jid, 'chats')
 		del self.contacts[jid]
 	
-	def new_user(self, contact):
+	def new_tab(self, contact):
 		'''when new tab is created'''
 		self.names[contact.jid] = contact.name
 		self.xmls[contact.jid] = gtk.glade.XML(GTKGUI_GLADE, 'chats_vbox', APP)
@@ -53,10 +53,10 @@ class TabbedChatWindow(chat.Chat):
 		self.show_title()
 		
-		# NOTE: if it not a window event, connect in new_user function
+		# NOTE: if it not a window event, connect in new_tab function
 		signal_dict = {
 'on_tabbed_chat_window_destroy': self.on_tabbed_chat_window_destroy,